@@ -1,6 +1,6 @@
 package Acme::Acferen;
 
-use warnings
+use warnings;
 use strict;
 
 =head1 NAME
@@ -9,11 +9,11 @@ Acme::Acferen - The great new Acme::Acferen!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
